PacmanConfig

Struct PacmanConfig 

#[non_exhaustive]
pub struct PacmanConfig { pub files: Option<HashMap<String, String>>, pub depends: Option<Dependencies>, pub provides: Option<Vec<String>>, pub conflicts: Option<Vec<String>>, pub replaces: Option<Vec<String>>, pub source: Option<Vec<String>>, }
The Linux pacman configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
files: Option<HashMap<String, String>>

List of custom files to add to the pacman package. Maps a dir/file to a dir/file inside the pacman package.

depends: Option<Dependencies>

List of softwares that must be installed for the app to build and run.

See : https://wiki.archlinux.org/title/PKGBUILD#depends

provides: Option<Vec<String>>

Additional packages that are provided by this app.

See : https://wiki.archlinux.org/title/PKGBUILD#provides

conflicts: Option<Vec<String>>

Packages that conflict or cause problems with the app. All these packages and packages providing this item will need to be removed

See : https://wiki.archlinux.org/title/PKGBUILD#conflicts

replaces: Option<Vec<String>>

Only use if this app replaces some obsolete packages. For example, if you rename any package.

See : https://wiki.archlinux.org/title/PKGBUILD#replaces

source: Option<Vec<String>>

Source of the package to be stored at PKGBUILD. PKGBUILD is a bash script, so version can be referred as ${pkgver}

Implementations

Source

impl PacmanConfig

pub fn new() -> Self

Creates a new PacmanConfig.

pub fn files<I, S, T>(self, files: I) -> Self
where I: IntoIterator<Item = (S, T)>, S: Into<String>, T: Into<String>,

Set the list of custom files to add to the pacman package. Maps a dir/file to a dir/file inside the pacman package.

pub fn depends<I, S>(self, depends: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Set the list of pacman dependencies directly using an iterator of strings.

pub fn depends_path<P>(self, path: P) -> Self
where P: Into<PathBuf>,

Set the list of pacman dependencies indirectly via a path to a file, which must contain one dependency (a package name) per line.

pub fn provides<I, S>(self, provides: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Set the list of additional packages that are provided by this app.

pub fn conflicts<I, S>(self, conflicts: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Set the list of packages that conflict with the app.

pub fn replaces<I, S>(self, replaces: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Set the list of obsolete packages that are replaced by this package.

pub fn source<I, S>(self, source: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Set the list of sources where the package will be stored.