#[non_exhaustive]pub struct AppImageConfig {
pub libs: Option<Vec<String>>,
pub bins: Option<Vec<String>>,
pub files: Option<HashMap<String, String>>,
pub linuxdeploy_plugins: Option<HashMap<String, String>>,
pub excluded_libs: Option<Vec<String>>,
}Expand description
The Linux AppImage configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.libs: Option<Vec<String>>List of libs that exist in /usr/lib* to be include in the final AppImage.
The libs will be searched for, using the command
find -L /usr/lib* -name <libname>
bins: Option<Vec<String>>List of binary paths to include in the final AppImage.
For example, if you want xdg-open, you’d specify /usr/bin/xdg-open
files: Option<HashMap<String, String>>List of custom files to add to the appimage package. Maps a dir/file to a dir/file inside the appimage package.
linuxdeploy_plugins: Option<HashMap<String, String>>A map of linuxdeploy
plugin name and its URL to be downloaded and executed while packaing the appimage.
For example, if you want to use the
gtk plugin,
you’d specify gtk as the key and its url as the value.
excluded_libs: Option<Vec<String>>List of globs of libraries to exclude from the final AppImage.
For example, to exclude libnss3.so, you’d specify libnss3*
Implementations
Sourceimpl AppImageConfig
impl AppImageConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new DebianConfig.
Sourcepub fn libs<I, S>(self, libs: I) -> Self
pub fn libs<I, S>(self, libs: I) -> Self
Set the list of libs that exist in /usr/lib* to be include in the final AppImage.
The libs will be searched for using, the command
find -L /usr/lib* -name <libname>
Sourcepub fn bins<I, S>(self, bins: I) -> Self
pub fn bins<I, S>(self, bins: I) -> Self
Set the list of binary paths to include in the final AppImage.
For example, if you want xdg-open, you’d specify /usr/bin/xdg-open
Sourcepub fn files<I, S, T>(self, files: I) -> Self
pub fn files<I, S, T>(self, files: I) -> Self
Set the list of custom files to add to the appimage package. Maps a dir/file to a dir/file inside the appimage package.
Sourcepub fn linuxdeploy_plugins<I, S, T>(self, linuxdeploy_plugins: I) -> Self
pub fn linuxdeploy_plugins<I, S, T>(self, linuxdeploy_plugins: I) -> Self
Set the map of linuxdeploy
plugin name and its URL to be downloaded and executed while packaing the appimage.
For example, if you want to use the
gtk plugin,
you’d specify gtk as the key and its url as the value.