#[non_exhaustive]pub struct PacmanConfig {
pub files: Option<HashMap<String, String>>,
pub depends: Option<Dependencies>,
pub provides: Option<Vec<String>>,
pub conflicts: Option<Vec<String>>,
pub replaces: Option<Vec<String>>,
pub source: Option<Vec<String>>,
}Expand description
The Linux pacman configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.files: Option<HashMap<String, String>>List of custom files to add to the pacman package. Maps a dir/file to a dir/file inside the pacman package.
depends: Option<Dependencies>List of softwares that must be installed for the app to build and run.
provides: Option<Vec<String>>Additional packages that are provided by this app.
conflicts: Option<Vec<String>>Packages that conflict or cause problems with the app. All these packages and packages providing this item will need to be removed
replaces: Option<Vec<String>>Only use if this app replaces some obsolete packages. For example, if you rename any package.
source: Option<Vec<String>>Source of the package to be stored at PKGBUILD. PKGBUILD is a bash script, so version can be referred as ${pkgver}
Implementations
Sourceimpl PacmanConfig
impl PacmanConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new PacmanConfig.
Sourcepub fn files<I, S, T>(self, files: I) -> Self
pub fn files<I, S, T>(self, files: I) -> Self
Set the list of custom files to add to the pacman package. Maps a dir/file to a dir/file inside the pacman package.
Sourcepub fn depends<I, S>(self, depends: I) -> Self
pub fn depends<I, S>(self, depends: I) -> Self
Set the list of pacman dependencies directly using an iterator of strings.
Sourcepub fn depends_path<P>(self, path: P) -> Self
pub fn depends_path<P>(self, path: P) -> Self
Set the list of pacman dependencies indirectly via a path to a file, which must contain one dependency (a package name) per line.
Sourcepub fn provides<I, S>(self, provides: I) -> Self
pub fn provides<I, S>(self, provides: I) -> Self
Set the list of additional packages that are provided by this app.
Sourcepub fn conflicts<I, S>(self, conflicts: I) -> Self
pub fn conflicts<I, S>(self, conflicts: I) -> Self
Set the list of packages that conflict with the app.
Sourcepub fn replaces<I, S>(self, replaces: I) -> Self
pub fn replaces<I, S>(self, replaces: I) -> Self
Set the list of obsolete packages that are replaced by this package.